CREATE TABLE CompanyLocations (locationID        SMALLINT  UNSIGNED PRIMARY KEY, 
                               locationName      CHAR(40)  NOT NULL   ,
      			       locationAddress   CHAR(80)  ,
			       parentLocationID  SMALLINT  UNSIGNED );

CREATE TABLE DriveRights (locationID        SMALLINT  UNSIGNED  NOT NULL, 
			  driveRightID      SMALLINT  UNSIGNED  NOT NULL,
 			  vehicleID         SMALLINT  UNSIGNED          ,
		          driveRightType    SMALLINT  UNSIGNED          , 
			  speedLimit        SMALLINT  UNSIGNED          ,
		          accelLimit        SMALLINT  UNSIGNED          ,
      			  decelLimit        SMALLINT  UNSIGNED          ,
		          settingsCode      SMALLINT  UNSIGNED          ,
                          stopTime          SMALLINT  UNSIGNED          ,
                          logOutTime        SMALLINT  UNSIGNED          ,
                          VSS               INT	      UNSIGNED          ,
                          pulsesPerReading  SMALLINT  UNSIGNED          ,
                          calibrationNumber INT	      UNSIGNED          ,
                          distanceUnit      CHAR(1)	 	        ,
      			  dateMode          CHAR(1)	 	        ,
		          timeMode          CHAR(1)	 	        ,
			  alarmMode         CHAR(1)	 	        ,
			  warnNotLogged     CHAR(1)	 	        ,
                          tamperLight       CHAR(1)                     ,
     		          activeField	    CHAR(1)  	     	        ,
                          remarks           CHAR(80)	   	        ,
	                  PRIMARY KEY (locationID, driveRightID) );

CREATE TABLE CarChips  (locationID        SMALLINT  UNSIGNED  NOT NULL,
			carChipID         SMALLINT  UNSIGNED  NOT NULL,   
	  		serialNumber      CHAR(20)  NOT NULL	      ,
	  		carChipType       SMALLINT  UNSIGNED  	      ,
      			vehicleID         SMALLINT  UNSIGNED  	      ,
     			driverID          SMALLINT  UNSIGNED  	      ,
      			speedBand1        SMALLINT  UNSIGNED  	      ,
	  		speedBand2        SMALLINT  UNSIGNED  	      ,
	  		speedBand3        SMALLINT  UNSIGNED  	      ,
      			hardBraking       FLOAT                       ,
	  		extremeBraking    FLOAT               	      ,
	  		hardAccel         FLOAT                       ,
	  		extremeAccel      FLOAT                       ,
      			parameter1        SMALLINT  UNSIGNED		      ,
      			interval1         SMALLINT  UNSIGNED		      ,
	  		parameter2        SMALLINT  UNSIGNED		      ,
      			interval2         SMALLINT  UNSIGNED		      ,
	  		parameter3        SMALLINT  UNSIGNED		      ,
      			interval3         SMALLINT  UNSIGNED	      ,
	  		parameter4        SMALLINT  UNSIGNED	      ,
      			interval4         SMALLINT  UNSIGNED		      ,
			PRIMARY KEY (locationID, carChipID) );

CREATE TABLE DriverGroups (locationID       SMALLINT  UNSIGNED  NOT NULL, 
		      	   groupNumber      SMALLINT  UNSIGNED  NOT NULL, 
			   groupName        CHAR(60)            NOT NULL, 
      			   remarks          CHAR(60)                    , 
			   PRIMARY KEY (locationID, groupNumber));

CREATE TABLE Drivers (locationID        SMALLINT  UNSIGNED  NOT NULL, 
   		      driverID          SMALLINT  UNSIGNED  NOT NULL, 
                      groupNumber       SMALLINT  UNSIGNED  	    , 
                      driverName        CHAR(60)            NOT NULL,
                      initials          CHAR(5)                     ,
                      address           CHAR(80)            	    ,
                      city_state        CHAR(60)            	    ,
                      zipCode           CHAR(20)            	    ,
                      phoneNumber       CHAR(20)            	    ,
                      email             CHAR(80)                    ,
                      companyName       CHAR(80)            	    ,
                      employeeID        CHAR(15)                    ,
     		      activeField	CHAR(1)  	   	    ,
                      remarks           CHAR(80)	   	    ,
	              PRIMARY KEY (locationID, driverID));

CREATE TABLE Fleets (locationID        SMALLINT  UNSIGNED  NOT NULL, 
                     fleetNumber       SMALLINT  UNSIGNED  NOT NULL, 
                     fleetName         CHAR(40)            NOT NULL,
         	     PRIMARY KEY (locationID, fleetNumber));

CREATE TABLE Vehicles (locationID        SMALLINT  UNSIGNED  NOT NULL, 
                       vehicleID         SMALLINT  UNSIGNED  NOT NULL, 
                       vehicleNumber     CHAR(80)	             ,
	               fleetNumber       SMALLINT  UNSIGNED  NOT NULL, 
                       driveRightID      SMALLINT  UNSIGNED  NOT NULL, 
                       driverID          SMALLINT  UNSIGNED  NOT NULL, 
                       make_model        CHAR(80)      	             ,
                       licensePlate      CHAR(20)  	             ,
                       color             CHAR(10)                    ,
                       purchaseDate      DATE             	     ,                       
                       currentOdometer   FLOAT               NOT NULL,
	               vehicleType       SMALLINT  UNSIGNED          , 
                       digitalInputs     CHAR(1)                     ,
	     	       activeField	 CHAR(1)  	   	     ,
                       remarks           CHAR(80)	   	     ,
       	               PRIMARY KEY (locationID, vehicleID));

CREATE TABLE Trips (locationID        SMALLINT  UNSIGNED  NOT NULL, 
	            driveRightID      SMALLINT  UNSIGNED  NOT NULL, 
	            driverID          SMALLINT  UNSIGNED  NOT NULL, 
                    startDateTime     DATETIME            NOT NULL,
                    endDateTime       DATETIME            NOT NULL,
                    tripTime          SMALLINT  UNSIGNED  NOT NULL, 
                    distance          FLOAT               NOT NULL, 
                    vehicleID         SMALLINT  UNSIGNED  NOT NULL, 
                    averageSpeed      SMALLINT  UNSIGNED  NOT NULL, 
                    topSpeed          SMALLINT  UNSIGNED  NOT NULL, 
                    timeOverSpeed     INT       UNSIGNED  NOT NULL, 
	            startOdometer     FLOAT               NOT NULL,
	            endOdometer       FlOAT               NOT NULL,
                    accelCount        SMALLINT  UNSIGNED  NOT NULL, 
                    decelCount        SMALLINT  UNSIGNED  NOT NULL, 
                    tripType          CHAR(1)	          NOT NULL,
	            fromAddress       SMALLINT  UNSIGNED          , 
                    toAddress         SMALLINT  UNSIGNED          , 
                    reason            CHAR(80)  		  ,
                    startState        CHAR(1)                     ,
                    endState          CHAR(1)	  	          ,
	            PRIMARY KEY (locationID, driveRightID, driverID, startDateTime));

CREATE TABLE TripAddresses (locationID        SMALLINT  UNSIGNED  NOT NULL, 
	                    addressID         SMALLINT  UNSIGNED  NOT NULL, 
                            name              CHAR(80)            NOT NULL,
                            companyName       CHAR(40)			  ,
                            contactPerson     CHAR(40)			  ,
                            address           CHAR(80)			  ,
                            city              CHAR(40)			  ,
                            state             CHAR(40)			  ,
                            zipCode           CHAR(40)			  ,
                            country           CHAR(40)			  ,
                            telephone         CHAR(20)			  ,
                            fax               CHAR(20)			  ,
                            email             CHAR(80)			  ,
                            latitude          FLOAT		 	  ,
                            longitude         FLOAT			  ,
                            elevation         FLOAT		  	  ,
                            addressRadius     SMALLINT  UNSIGNED  	  , 
                            ExtraStr          CHAR(80)			  ,
                            ExtraInt1         SMALLINT			  ,
                            ExtraInt2         SMALLINT			  ,
	                    PRIMARY KEY (locationID, addressID));

CREATE TABLE TamperLogs (locationID        SMALLINT  UNSIGNED  NOT NULL, 
                         driveRightID      SMALLINT  UNSIGNED  NOT NULL, 
	                 tamperDateTime    DATETIME  	       NOT NULL,
	                 downloadDateTime  DATETIME	               ,
                         driverID          SMALLINT  UNSIGNED  NOT NULL, 
	                 cause             SMALLINT  UNSIGNED  NOT NULL, 
	                 PRIMARY KEY (locationID, driveRightID, tamperDateTime, cause));


CREATE TABLE AccidentLogs (locationID         SMALLINT  UNSIGNED  NOT NULL, 
         		   driveRightID       SMALLINT  UNSIGNED  NOT NULL, 
		 	   accidentDateTime   DATETIME            NOT NULL,
                           driverID           SMALLINT            NOT NULL,
                           realOrDecel        CHAR(1)	 	  NOT NULL,
                           cause	      CHAR(1)			  ,
                           before_T19         SMALLINT  UNSIGNED          ,
                           brakeBefore_T19    CHAR(1) 			  ,
                           before_T18         SMALLINT  UNSIGNED          ,
                           brakeBefore_T18    CHAR(1) 			  ,
                           before_T17         SMALLINT  UNSIGNED          ,
                           brakeBefore_T17    CHAR(1) 			  ,
                           before_T16         SMALLINT  UNSIGNED          ,
                           brakeBefore_T16    CHAR(1) 			  ,
                           before_T15         SMALLINT  UNSIGNED          ,
                           brakeBefore_T15    CHAR(1) 			  ,
                           before_T14         SMALLINT  UNSIGNED          ,
                           brakeBefore_T14    CHAR(1) 			  ,
                           before_T13         SMALLINT  UNSIGNED          ,
                           brakeBefore_T13    CHAR(1) 			  ,
                           before_T12         SMALLINT  UNSIGNED          ,
                           brakeBefore_T12    CHAR(1) 			  ,
                           before_T11         SMALLINT  UNSIGNED          ,
                           brakeBefore_T11    CHAR(1) 			  ,
                           before_T10         SMALLINT  UNSIGNED          ,
                           brakeBefore_T10    CHAR(1) 			  ,
                           before_T09         SMALLINT  UNSIGNED          ,
                           brakeBefore_T09    CHAR(1) 			  ,
                           before_T08         SMALLINT  UNSIGNED          ,
                           brakeBefore_T08    CHAR(1) 			  ,
                           before_T07         SMALLINT  UNSIGNED          ,
                           brakeBefore_T07    CHAR(1) 			  ,
                           before_T06         SMALLINT  UNSIGNED          ,
                           brakeBefore_T06    CHAR(1) 			  ,
                           before_T05         SMALLINT  UNSIGNED          ,
                           brakeBefore_T05    CHAR(1) 			  ,
                           before_T04         SMALLINT  UNSIGNED          ,
                           brakeBefore_T04    CHAR(1) 			  ,
                           before_T03         SMALLINT  UNSIGNED          ,
                           brakeBefore_T03    CHAR(1) 			  ,
                           before_T02         SMALLINT  UNSIGNED          ,
                           brakeBefore_T02    CHAR(1) 			  ,
                           before_T01         SMALLINT  UNSIGNED          ,
                           brakeBefore_T01    CHAR(1) 			  ,
	                   time_T0            SMALLINT  UNSIGNED          ,
                           brakeAt_T0	      CHAR(1) 			  ,
	                   after_T01          SMALLINT  UNSIGNED          ,
                           brakeAfter_T01     CHAR(1) 			  ,
	                   after_T02          SMALLINT  UNSIGNED          ,
                           brakeAfter_T02     CHAR(1) 			  ,
	                   after_T03          SMALLINT  UNSIGNED          ,
                           brakeAfter_T03     CHAR(1) 			  ,
	                   after_T04          SMALLINT  UNSIGNED          ,
                           brakeAfter_T04     CHAR(1) 			  ,
	                   after_T05          SMALLINT  UNSIGNED          ,
                           brakeAfter_T05     CHAR(1) 			  ,
	                   after_T06          SMALLINT  UNSIGNED          ,
                           brakeAfter_T06     CHAR(1) 			  ,
	                   after_T07          SMALLINT  UNSIGNED          ,
                           brakeAfter_T07     CHAR(1) 			  ,
	                   after_T08          SMALLINT  UNSIGNED          ,
                           brakeAfter_T08     CHAR(1) 			  ,
	                   after_T09          SMALLINT  UNSIGNED          ,
                           brakeAfter_T09     CHAR(1) 			  ,
	                   after_T10          SMALLINT  UNSIGNED          ,
                           brakeAfter_T10     CHAR(1) 			  ,
	                   after_T11          SMALLINT  UNSIGNED          ,
                           brakeAfter_T11     CHAR(1) 			  ,
	                   after_T12          SMALLINT  UNSIGNED          ,
                           brakeAfter_T12     CHAR(1) 			  ,
	                   after_T13          SMALLINT  UNSIGNED          ,
                           brakeAfter_T13     CHAR(1) 			  ,
	                   after_T14          SMALLINT  UNSIGNED          ,
                           brakeAfter_T14     CHAR(1) 			  ,
	                   after_T15          SMALLINT  UNSIGNED          ,
                           brakeAfter_T15     CHAR(1) 			  ,
	                   after_T16          SMALLINT  UNSIGNED          ,
                           brakeAfter_T16     CHAR(1) 			  ,
	                   after_T17          SMALLINT  UNSIGNED          ,
                           brakeAfter_T17     CHAR(1) 			  ,
	                   after_T18          SMALLINT  UNSIGNED          ,
                           brakeAfter_T18     CHAR(1) 			  ,
	                   after_T19          SMALLINT  UNSIGNED          ,
                           brakeAfter_T19     CHAR(1) 			  ,
	                   after_T20          SMALLINT  UNSIGNED          ,
                           brakeAfter_T20     CHAR(1) 			  ,
	                   latitude           FLOAT			  ,
	                   longitude          FLOAT			  ,
	                   PRIMARY KEY (locationID, driveRightID, accidentDateTime));

CREATE TABLE Days (locationID        SMALLINT  UNSIGNED  NOT NULL, 
                   driveRightID      SMALLINT  UNSIGNED  NOT NULL, 
                   dayDate           DATE                NOT NULL,
                   day               SMALLINT  UNSIGNED  NOT NULL, 
                   driverID          SMALLINT  UNSIGNED  NOT NULL, 
	           totalDistance     FLOAT                       ,
	           highSpeed         SMALLINT  UNSIGNED          ,
	           timeOfHighSpeed   SMALLINT  UNSIGNED          ,
	           timeOverSpeed     SMALLINT  UNSIGNED          ,
	           totalTime         SMALLINT  UNSIGNED          ,
	           accelCount        SMALLINT  UNSIGNED          ,
	           decelCount        SMALLINT  UNSIGNED          ,
	           speedLimit        SMALLINT  UNSIGNED          ,
                   accelLimit        SMALLINT  UNSIGNED          ,
                   decelLimit        SMALLINT  UNSIGNED          ,
                   driveRightType    SMALLINT  UNSIGNED          ,
	           firstMove         SMALLINT  UNSIGNED          ,
	           lastMove          SMALLINT  UNSIGNED          ,
	           timeInMotion      SMALLINT  UNSIGNED          ,
	           highAccel         SMALLINT  UNSIGNED          ,
	           highAccelTime     SMALLINT  UNSIGNED          ,
  	           PRIMARY KEY (locationID, driveRightID, dayDate));

CREATE TABLE DownloadDates (locationID        SMALLINT  UNSIGNED  NOT NULL, 
                            driveRightID      SMALLINT  UNSIGNED  NOT NULL, 
                            downloadDate      DATE                NOT NULL,
                            daysSince         SMALLINT  UNSIGNED  NOT NULL, 
                            driverID          SMALLINT  UNSIGNED  NOT NULL, 
	                    PRIMARY KEY (locationID, driveRightID, downloadDate));

CREATE TABLE Password (locationID        SMALLINT  UNSIGNED  NOT NULL, 
                       userName          CHAR(40)            NOT NULL,
                       password          CHAR(40)            NOT NULL,
                       userType          CHAR(1)             NOT NULL,
                       driveRtAccess     CHAR(1)             NOT NULL,
	               drBackup          CHAR(1) 	  	     ,
	               drRestore         CHAR(1) 	  	     ,
	               drImport          CHAR(1) 	  	     ,
	               drExport          CHAR(1) 	  	     ,
	               drPreferences     CHAR(1) 	  	     ,
	               drMaintenance     CHAR(1) 	  	     ,
	               reports           CHAR(1) 	  	     ,
	               locations         CHAR(1) 	  	     ,
	               driveRights       CHAR(1) 	  	     ,
	               driverGroups      CHAR(1) 	  	     ,
	               drivers           CHAR(1) 	  	     ,
	               fleets            CHAR(1) 	  	     ,
	               vehicles          CHAR(1) 	  	     ,
	               trips             CHAR(1) 	  	     ,
	               accidentLogs      CHAR(1) 	  	     ,
	               tamperLogs        CHAR(1) 	  	     ,
	               addresses         CHAR(1) 	  	     ,
	               days              CHAR(1) 	  	     ,
	               downloadDates     CHAR(1) 	  	     ,
	               gps               CHAR(1) 	  	     ,
		       odometerLogs      CHAR(1) 	  	     ,
		       safetyScore       CHAR(1) 	  	     ,
	               PRIMARY KEY (userName));

CREATE TABLE GPS (locationID        SMALLINT  UNSIGNED  NOT NULL, 
                  driveRightID      SMALLINT  UNSIGNED  NOT NULL, 
                  gpsDateTime       DATE                NOT NULL,
                  day               SMALLINT  UNSIGNED          ,
                  driverID          SMALLINT  UNSIGNED          ,
	          speed		    SMALLINT  UNSIGNED          ,
	          direction	    FLOAT 	                ,
	          highSpeed         SMALLINT  UNSIGNED          ,
	          latitude          FLOAT(10,5)	                ,
	          longitude         FLOAT(10,5)                 ,
	          gpsStatus         INT       UNSIGNED          ,
	          vehicleState      CHAR(1)                     ,
                  PRIMARY KEY (locationID, driveRightID, gpsDateTime));

CREATE TABLE OdometerLogs (locationID         SMALLINT  UNSIGNED  NOT NULL,
                           driveRightID       SMALLINT  UNSIGNED  NOT NULL,
  	                   adjustmentDateTime DATETIME            NOT NULL,
                           vehicleID          SMALLINT  UNSIGNED  NOT NULL,
                           odometerValue      FLOAT 	UNSIGNED  NOT NULL,
	                   cause              CHAR(40)          	  ,
	                   PRIMARY KEY (locationID, driveRightID, adjustmentDateTime));



CREATE TABLE SafetyScore  (locationID         SMALLINT  UNSIGNED  NOT NULL,
                           driverID           SMALLINT  UNSIGNED  NOT NULL,
  							year               SMALLINT  UNSIGNED  NOT NULL,
                           month              SMALLINT  UNSIGNED  NOT NULL,                           
                           exemptDriver	      CHAR(1)		,
							score	      SMALLINT  	,
							mileage	      FLOAT  		,
							vehicleType        CHAR(1)             NOT NULL,
							recalcScore       CHAR(1)	     			 , ;
							extraByte         CHAR(1)           	     	 , ;
							extraInt1         INT                        , ;
							extraInt2         INT                        , ;
							extraFloat        FLOAT					 , ;
	                   PRIMARY KEY (locationID, driverID, year, month, vehicleType));


















